[PATCH 2/2] status: show commit sha1 in "You are currently reverting" message

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Signed-off-by: Matthieu Moy <Matthieu.Moy@xxxxxxx>
---
 t/t7512-status-help.sh | 7 ++++---
 wt-status.c            | 8 ++++++--
 wt-status.h            | 1 +
 3 files changed, 11 insertions(+), 5 deletions(-)

diff --git a/wt-status.c b/wt-status.c
index 5123c71..e956910 100644
--- a/wt-status.c
+++ b/wt-status.c
@@ -969,7 +969,8 @@ static void show_revert_in_progress(struct wt_status *s,
 					struct wt_status_state *state,
 					const char *color)
 {
-	status_printf_ln(s, color, _("You are currently reverting a commit."));
+	status_printf_ln(s, color, _("You are currently reverting commit %s."),
+			 find_unique_abbrev(state->revert_head_sha1, DEFAULT_ABBREV));
 	if (advice_status_hints) {
 		if (has_unmerged(s))
 			status_printf_ln(s, color,
@@ -1105,6 +1106,7 @@ void wt_status_get_state(struct wt_status_state *state,
 			 int get_detached_from)
 {
 	struct stat st;
+	unsigned char sha1[20];
 
 	if (!stat(git_path("MERGE_HEAD"), &st)) {
 		state->merge_in_progress = 1;
@@ -1132,8 +1134,10 @@ void wt_status_get_state(struct wt_status_state *state,
 		state->bisect_in_progress = 1;
 		state->branch = read_and_strip_branch("BISECT_START");
 	}
-	if (!stat(git_path("REVERT_HEAD"), &st)) {
+	if (!stat(git_path("REVERT_HEAD"), &st) &&
+	    !get_sha1("REVERT_HEAD", sha1)) {
 		state->revert_in_progress = 1;
+		hashcpy(state->revert_head_sha1, sha1);
 	}
 
 	if (get_detached_from)
diff --git a/wt-status.h b/wt-status.h
index 35cd6cb..4121bc2 100644
--- a/wt-status.h
+++ b/wt-status.h
@@ -85,6 +85,7 @@ struct wt_status_state {
 	char *onto;
 	char *detached_from;
 	unsigned char detached_sha1[20];
+	unsigned char revert_head_sha1[20];
 };
 
 void wt_status_prepare(struct wt_status *s);
diff --git a/t/t7512-status-help.sh b/t/t7512-status-help.sh
index d745cf4..bf08d4e 100755
--- a/t/t7512-status-help.sh
+++ b/t/t7512-status-help.sh
@@ -686,10 +686,11 @@ test_expect_success 'status while reverting commit (conflicts)' '
 	test_commit old to-revert.txt &&
 	echo new >to-revert.txt &&
 	test_commit new to-revert.txt &&
-	test_must_fail git revert HEAD^ &&
+	TO_REVERT=$(git rev-parse --short HEAD^) &&
+	test_must_fail git revert $TO_REVERT &&
 	cat >expected <<-EOF
 	# On branch master
 	# You are currently reverting a commit.
 	#   (fix conflicts and run "git revert --continue")
 	#   (use "git revert --abort" to cancel the revert operation)
 	#
@@ -710,7 +711,7 @@ test_expect_success 'status while reverting commit (conflicts resolved)' '
 	git add to-revert.txt &&
 	cat >expected <<-EOF
 	# On branch master
 	# You are currently reverting a commit.
 	#   (all conflicts fixed: run "git revert --continue")
 	#   (use "git revert --abort" to cancel the revert operation)
 	#
@@ -686,10 +686,11 @@ test_expect_success 'status while reverting commit (conflicts)' '
 	cat >expected <<-EOF
 	# On branch master
-	# You are currently reverting a commit.
+	# You are currently reverting commit $TO_REVERT.
 	#   (fix conflicts and run "git revert --continue")
 	#   (use "git revert --abort" to cancel the revert operation)
@@ -710,7 +711,7 @@ test_expect_success 'status while reverting commit (conflicts resolved)' '
 	cat >expected <<-EOF
 	# On branch master
-	# You are currently reverting a commit.
+	# You are currently reverting commit $TO_REVERT.
 	#   (all conflicts fixed: run "git revert --continue")
 	#   (use "git revert --abort" to cancel the revert operation)
-- 
1.8.2.359.g6e2e2c6.dirty

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html




[Index of Archives]     [Linux Kernel Development]     [Gcc Help]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [V4L]     [Bugtraq]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]     [Fedora Users]